graphium.trainer
====================

Code for training models

=== "Contents"
    * [Predictor](#predictor)
    * [Metrics](#metrics)
    * [Predictor Summaries](#predictor-summaries)
    * [Predictor Options](#predictor-options)


## Predictor
------------
::: graphium.trainer.predictor


## Metrics
------------
::: graphium.trainer.metrics


## Predictor Summaries
------------
::: graphium.trainer.predictor_summaries


## Predictor Options
------------
::: graphium.trainer.predictor_options


